@@ -1,7 +1,6 @@
 from netifaces import interfaces, ifaddresses, AF_INET
 import re
 from memsql.common.connection_pool import ConnectionPool
-from wraptor.decorators import memoize
 
 # Status variables specified in the following array will be sent to
 # collectd as COUNTERS as well as GAUGES.
@@ -66,14 +65,6 @@ class Node(object):
             password="",
             database="information_schema")
 
-    @memoize(instance_method=True, timeout=3600)
-    def data_directory(self):
-        with self.connect() as conn:
-            row = conn.get('SHOW STATUS EXTENDED LIKE "Data_directory"')
-
-        if row and row.Value:
-            return row.Value
-
     def status(self):
         with self.connect() as conn:
             rows = conn.query('SHOW STATUS EXTENDED')
